#!/usr/bin/env python
"""
	This software was developed by the University of Tennessee as part of the
	Distributed Data Analysis of Neutron Scattering Experiments (DANSE)
	project funded by the US National Science Foundation.

	If you use DANSE applications to do scientific research that leads to
	publication, we ask that you acknowledge the use of the software with the
	following sentence:

	"This work benefited from DANSE software developed under NSF award DMR-0520547."

	copyright 2008, University of Tennessee
"""

""" Provide functionality for a C extension model

	WARNING: THIS FILE WAS GENERATED BY WRAPPERGENERATOR.PY
 	         DO NOT MODIFY THIS FILE, MODIFY ../c_extensions/ellipsoid.h
 	         AND RE-RUN THE GENERATOR SCRIPT

"""

from sans.models.BaseComponent import BaseComponent
from sans_extension.c_models import CEllipsoidModel
import copy    
    
class EllipsoidModel(CEllipsoidModel, BaseComponent):
    """ Class that evaluates a EllipsoidModel model. 
    	This file was auto-generated from ../c_extensions/ellipsoid.h.
    	Refer to that file and the structure it contains
    	for details of the model.
    	List of default parameters:
         scale           = 1.0 
         radius_a        = 20.0 A
         radius_b        = 400.0 A
         contrast        = 3e-006 A-2
         background      = 0.0 cm-1
         axis_theta      = 1.57 rad
         axis_phi        = 0.0 rad

    """
        
    def __init__(self):
        """ Initialization """
        
        # Initialize BaseComponent first, then sphere
        BaseComponent.__init__(self)
        CEllipsoidModel.__init__(self)
        
        ## Name of the model
        self.name = "EllipsoidModel"
        self.description =""""P(q.alpha)= scale*f(q)^(2)+ bkg\n\
		f(q)= 3*(scatter_sld- scatter_solvent)*V*[sin(q*r(Ra,Rb,alpha)) - q*r*cos(qr(Ra,Rb,alpha))]
		/[qr(Ra,Rb,alpha)]^(3)"
		r(Ra,Rb,alpha)= [Rb^(2)*(sin(alpha))^(2) + Ra^(2)*(cos(alpha))^(2)]^(1/2)
		scatter_sld: scattering length density of the scatter
		solvent_sld: scattering length density of the solvent
		V: volune of the Eliipsoid
		Ra: radius along the rotation axis of the Ellipsoid
		Rb: radius perpendicular to the rotation axis of the ellipsoid"""
		## Parameter details [units, min, max]
        self.details = {}
        self.details['scale'] = ['', None, None]
        self.details['radius_a'] = ['A', None, None]
        self.details['radius_b'] = ['A', None, None]
        self.details['contrast'] = ['A-2', None, None]
        self.details['background'] = ['cm-1', None, None]
        self.details['axis_theta'] = ['rad', None, None]
        self.details['axis_phi'] = ['rad', None, None]

   
    def clone(self):
        """ Return a identical copy of self """
        return self._clone(EllipsoidModel())   
   
    def run(self, x = 0.0):
        """ Evaluate the model
            @param x: input q, or [q,phi]
            @return: scattering function P(q)
        """
        
        return CEllipsoidModel.run(self, x)
   
    def runXY(self, x = 0.0):
        """ Evaluate the model in cartesian coordinates
            @param x: input q, or [qx, qy]
            @return: scattering function P(q)
        """
        
        return CEllipsoidModel.runXY(self, x)
        
    def set_dispersion(self, parameter, dispersion):
        """
            Set the dispersion object for a model parameter
            @param parameter: name of the parameter [string]
            @dispersion: dispersion object of type DispersionModel
        """
        return CEllipsoidModel.set_dispersion(self, parameter, dispersion.cdisp)
        
   
# End of file
